@@ -15,8 +15,8 @@ from pythautomata.automata.wheighted_automaton_definition.weighted_state import
 import numpy as np
 
 class BoundedPDFAQuantizationNAryTreeLearner(PDFAQuantizationNAryTreeLearner):
-    def __init__(self, partitioner, max_states, max_query_length, max_seconds_run=None, generate_partial_hipothesis = False, pre_cache_queries_for_building_hipothesis = False, check_probabilistic_hipothesis = True, exhaust_counterexample = False, mean_distribution_for_partial_hipothesis = False):
-        super().__init__(partitioner, pre_cache_queries_for_building_hipothesis, check_probabilistic_hipothesis, exhaust_counterexample)
+    def __init__(self, partitioner, max_states, max_query_length, max_seconds_run=None, generate_partial_hipothesis = False, pre_cache_queries_for_building_hipothesis = False, check_probabilistic_hipothesis = True, exhaust_counterexample = False, mean_distribution_for_partial_hipothesis = False, omit_zero_transitions = False):
+        super().__init__(partitioner, pre_cache_queries_for_building_hipothesis, check_probabilistic_hipothesis, exhaust_counterexample, omit_zero_transitions)
         self._max_states = max_states
         self._max_query_length = max_query_length
         self._max_seconds_run = max_seconds_run
@@ -86,9 +86,9 @@ class BoundedPDFAQuantizationNAryTreeLearner(PDFAQuantizationNAryTreeLearner):
         for leaf_str, leaf in self._tree.leaves.items():
             initial_weight = 1 if leaf_str == epsilon else 0
             terminal_symbol_probability = leaf.probabilities[self.terminal_symbol]
-            state = WeightedState(leaf_str, initial_weight, terminal_symbol_probability)
+            state = WeightedState(leaf_str, initial_weight, terminal_symbol_probability, terminal_symbol=self.terminal_symbol)
             states[leaf_str] = state
-        unknown_state =  WeightedState(self._tree.unknown_leaf, 0, -1)     
+        unknown_state =  WeightedState(self._tree.unknown_leaf, 0, -1, terminal_symbol=self.terminal_symbol)     
         partial_distributions = []
         states[self._tree.unknown_leaf] = unknown_state
         accessed_states = set()
