@@ -48,21 +48,26 @@ class KearnsVaziraniLearner(Learner):
             while not are_equivalent:
                 self.update_tree(counterexample, model)
                 model = self.tentative_hypothesis()
-                are_equivalent, counterexample = self._teacher.equivalence_query(model)                
+                if self._teacher.membership_query(counterexample) == model.accepts(counterexample):
+                    are_equivalent, counterexample = self._teacher.equivalence_query(model)
+                            
+        # Convert state names into strings
+        for state in model.states:
+            state.name = str(state.name)
 
         numberOfStates = len(model.states) if model is not None else 0
         info = {
             'equivalence_queries_count': self._teacher.equivalence_queries_count,
             'membership_queries_count': self._teacher.membership_queries_count,
-            'observation_tree': self._tree
+            'observation_tree': self._tree,
         }
         return LearningResult(model, numberOfStates, info)
-
+    
     def tentative_hypothesis(self) -> DFA:
         states = {}
         for leaf in self._tree.leaves:
             is_final = self._tree._ask_membership_query(leaf)
-            state = State(leaf, is_final)
+            state = State(leaf, is_final, access_string=leaf)
             states[leaf] = state
         
         for access_string, state in states.items():
@@ -100,7 +105,7 @@ class KearnsVaziraniLearner(Learner):
         assert(distinguishing_string_found, 'Some distinguishing string must have been found, if not an infinite loop occurs')
 
     def create_single_state_DFA(self, is_final: bool):
-        epsilonState = State(epsilon, is_final=is_final)
+        epsilonState = State(epsilon, is_final=is_final, access_string=epsilon)
         for symbol in self._symbols:
             epsilonState.add_transition(symbol, epsilonState)
         return DFA(self._alphabet, epsilonState, set([epsilonState]), None)
