@@ -12,16 +12,18 @@ from pymodelextractor.learners.learning_result import LearningResult
 from pymodelextractor.exceptions.query_length_exceeded_exception import QueryLengthExceededException
 from collections import OrderedDict
 import math
+import warnings
 
 
 class PDFAQuantizationNAryTreeLearner:
-    def __init__(self, probabilityPartitioner: ProbabilityPartitioner, pre_cache_queries_for_building_hipothesis = False, check_probabilistic_hipothesis = True, exhaust_counterexample = False):
+    def __init__(self, probabilityPartitioner: ProbabilityPartitioner, pre_cache_queries_for_building_hipothesis = False, check_probabilistic_hipothesis = True, exhaust_counterexample = False, omit_zero_transitions = False):
         self.probability_partitioner = probabilityPartitioner
         self._pre_cache_queries_for_building_hipothesis = pre_cache_queries_for_building_hipothesis
         self._verbose = False
         self._tree = None
         self._check_probabilistic_hipothesis = check_probabilistic_hipothesis
         self._exhaust_counterexample = exhaust_counterexample
+        self._omit_zero_transitions = omit_zero_transitions
         pass
 
     @property
@@ -43,6 +45,16 @@ class PDFAQuantizationNAryTreeLearner:
 
     def _perform_next_token_probabilities(self, value):
         return self._teacher.next_token_probabilities(value)
+    
+    def _is_counterexample(self, sequence, hypothesis):
+        teacher_probs = list(self._perform_next_token_probabilities(sequence).values())
+        hypothesis_probs = hypothesis.last_token_probabilities(sequence, self._all_symbols_sorted)
+        return teacher_probs!=hypothesis_probs
+
+    def _shorten_counterexample(self, counterexample, hypothesis):
+        for prefix in counterexample.get_prefixes():
+            if self._is_counterexample(prefix, hypothesis):
+                return prefix
 
     def initialization(self, verbose) -> tuple[bool, ProbabilisticDeterministicFiniteAutomaton]:
         probabilities = self._perform_next_token_probabilities(epsilon)
@@ -52,6 +64,9 @@ class PDFAQuantizationNAryTreeLearner:
             self._tree = None
             return True, starting_pdfa
 
+        if self._omit_zero_transitions:
+            counterexample = self._shorten_counterexample(counterexample, starting_pdfa)
+
         next_token_probabilities_epsilon = self._perform_next_token_probabilities(epsilon)
         next_token_probabilities_counterexample = self._perform_next_token_probabilities(counterexample)
         nodeRoot = ClassificationNode(epsilon)
@@ -75,9 +90,11 @@ class PDFAQuantizationNAryTreeLearner:
         models = []
         is_target_DFA, model = self.initialization(verbose)
         symbols = list(self._alphabet.symbols)
+        epsilon_probablity = self._teacher.next_token_probabilities(Sequence())
         if not is_target_DFA:
             for symbol in symbols:
-                self._tree.sift(Sequence([symbol]))
+                if epsilon_probablity[symbol] != 0 or not self._omit_zero_transitions:
+                    self._tree.sift(Sequence([symbol]))
             
             model = self.tentative_hypothesis()
             models.append(model)
@@ -91,7 +108,8 @@ class PDFAQuantizationNAryTreeLearner:
                 models.append(model)
                 size = len(model.weighted_states)
                 if verbose: print('Size after update:', size)
-                assert size > last_size, 'Possible infinite loop'
+                if size == last_size:
+                    warnings.warn('Possible infinite loop, last hipothesis has the same size as current hipothesis.\nSize: '+str(size))
                 last_size = size
                 
                 teacher_prob = list(self._teacher.next_token_probabilities(counterexample).values())                
@@ -135,19 +153,33 @@ class PDFAQuantizationNAryTreeLearner:
             for leaf_str, leaf in self._tree.leaves.items():
                 initial_weight = 1 if leaf_str == epsilon else 0
                 terminal_symbol_probability = leaf.probabilities[self.terminal_symbol]
-                state = WeightedState(leaf_str, initial_weight, terminal_symbol_probability)
+                state = WeightedState(leaf_str, initial_weight, terminal_symbol_probability, terminal_symbol=self.terminal_symbol)
                 states[leaf_str] = state
 
             for access_string, state in states.items():
                 for symbol in symbols:
-                    access_string_of_transition, updated_tree = self._tree.sift(access_string + symbol)
-                    if updated_tree:
-                        break
-                    state.add_transition(symbol, states[access_string_of_transition],
-                                         self._tree.leaves[access_string].probabilities[symbol])
+                    if self._tree.leaves[access_string].probabilities[symbol] > 0 or not self._omit_zero_transitions:
+                        access_string_of_transition, updated_tree = self._tree.sift(access_string + symbol)
+                        if updated_tree:
+                            break
+                        state.add_transition(symbol, states[access_string_of_transition],
+                                            self._tree.leaves[access_string].probabilities[symbol])
                 if updated_tree:
                     break
 
+        if self._omit_zero_transitions:
+            hole = WeightedState("HOLE", 0, 1, terminal_symbol=self.terminal_symbol)
+            for symbol in symbols:
+                hole.add_transition(symbol, hole, 0)
+            added_transitions = 0
+            for access_string, state in states.items():
+                for symbol in symbols:
+                    if symbol not in state.transitions_set:
+                        state.add_transition(symbol, hole, 0)
+                        added_transitions+=1                        
+            if added_transitions > 0:
+                states[hole.name] = hole
+
         comparator = WFAToleranceComparator()
         states = set(states.values())
         return PDFA(self._alphabet, states, self.terminal_symbol, comparator=comparator, check_is_probabilistic=self._check_probabilistic_hipothesis)
@@ -179,10 +211,21 @@ class PDFAQuantizationNAryTreeLearner:
     def create_single_state_PDFA(self, probabilities: OrderedDict[Symbol, float]):
         final_weight = probabilities[self.terminal_symbol]
         probabilities.pop(self.terminal_symbol)
-        initialState = WeightedState(epsilon, 1, final_weight=final_weight)
+        initialState = WeightedState(epsilon, 1, final_weight=final_weight, terminal_symbol=self.terminal_symbol)
+        states = {initialState}
+        hole = None
+        if self._omit_zero_transitions:
+            hole = WeightedState("HOLE", 0, 1, terminal_symbol=self.terminal_symbol)
+            for symbol in probabilities.keys():
+                hole.add_transition(symbol, hole, 0)
+            states.add(hole)            
         for symbol, probability in probabilities.items():
-            initialState.add_transition(symbol, initialState, probability)
-        return PDFA(self._alphabet, {initialState}, self.terminal_symbol, comparator=WFAToleranceComparator(), check_is_probabilistic=self._check_probabilistic_hipothesis)
+            if probability > 0 or not self._omit_zero_transitions:
+                initialState.add_transition(symbol, initialState, probability)
+            else:
+                
+                initialState.add_transition(symbol, hole, probability)            
+        return PDFA(self._alphabet, states, self.terminal_symbol, comparator=WFAToleranceComparator(), check_is_probabilistic=self._check_probabilistic_hipothesis)
 
 
 class ClassificationTree:
